七宗罪 (豆瓣)
Description: 七宗罪电影简介和剧情介绍,七宗罪影评、图片、预告片、影讯、论坛、在线购票
Keywords: 七宗罪,Se7en,七宗罪影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.92豆瓣电影Top250

# 七宗罪 Se7en (1995)

导演: 大卫·芬奇
编剧: 安德鲁·凯文·沃克
主演: 摩根·弗里曼 / 布拉德·皮特 / 凯文·史派西 / 格温妮斯·帕特洛 / 安德鲁·凯文·沃克 / 约翰·卡西尼 / 雷格·E·凯蒂 / 李·厄米
类型: 剧情 / 悬疑 / 惊悚 / 犯罪
制片国家/地区: 美国
语言: 英语
上映日期: 1995-09-22(美国)
片长: 127分钟
又名: 火线追缉令(台) / 7宗罪 / Seven
IMDb: tt0114369
豆瓣评分
引用
8.8
904325人评价
5星
50.9%
4星
39.5%
3星
8.9%
2星
0.6%
1星
0.2%
好于 98% 悬疑片
好于 98% 犯罪片
想看 看过
评价:
推荐

## 七宗罪的剧情简介 · · · · · ·

“暴食”、“贪婪”、“懒惰”、“嫉妒”、“骄傲”、“淫欲”、“愤怒”，这是天主教教义所指的人性七宗罪。城市中发生的连坏杀人案，死者恰好都是犯有这些教义的人。凶手故弄玄虚的作案手法，令资深冷静的警员沙摩塞（摩根•弗里曼 Morgan Freeman 饰）和血气方刚的新扎警员米尔斯（布拉德•皮特 Brad Pitt 饰）都陷入了破案的谜团中。他们去图书馆研读但丁的《神曲》，企图从人间地狱的描绘中找到线索，最后从宗教文学哲学的世界中找到了凶手作案计划和手段的蛛丝马迹。凶手前来投案自首，这令众人都松了一口气，以为案件就此结束，怎料还是逃不出七宗罪的杀人逻辑，这次凶手瞄准的目标，是那个犯了“愤怒”罪的人…… ©豆瓣

## 七宗罪的演职员 · · · · · · ( 全部 27 )

- 大卫·芬奇 导演
- 摩根·弗里曼 饰 Somerset
- 布拉德·皮特 饰 Mills
- 凯文·史派西 饰 John Doe
- 格温妮斯·帕特洛 饰 Tracy
- 安德鲁·凯文·沃克 饰 Dead Man at 1st Crime Scene

## 七宗罪的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片755 · 添加 )

## 七宗罪的获奖情况 · · · · · · ( 全部 )

- 第68届奥斯卡金像奖
- 最佳剪辑(提名)
- 理查德·弗朗西斯-布鲁斯

- 第49届英国电影学院奖
- 电影奖 最佳原创剧本(提名)
- 安德鲁·凯文·沃克

- 第20届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  记忆碎片

  禁闭岛

  沉默的羔羊

  致命ID

  看不见的客人

  杀人回忆

  搏击俱乐部

  非常嫌疑犯

  恐怖游轮

  猫鼠游戏

我要写短评

## 七宗罪的短评 · · · · · · ( 全部 144978 条 )

热门 / 最新 / 好友

### 2513 有用 催眠药 看过 2011-08-13 21:34:27

故事看多后的后遗症就是一般最后半小时就知道结局了。。。

### 4178 有用 星尘战场 看过 2007-02-17 17:10:36

里面的布拉德皮特帅的掉渣……

### 1395 有用 蛮爷 看过 2007-12-21 00:03:12

为什么拍出来十几年我才看到呢？

### 1942 有用 某猪·坑坑洼洼 看过 2010-03-20 23:40:54

没觉得有多经典。一来因为没有读圣经信基督的文化背景，二来就像那篇最热门的影评说的，它展示了一些很糟糕的东西，却没有给出解答。这没有什么意义。

### 830 有用 momo 看过 2016-11-01 01:23:41

色调太深沉，纽约的雨一直下，混乱的街区，血腥的现场。 有些画面好恶心，分2天看完的，特别喜欢老警察，演技台词都是一流的。 还有万万没想到的结局。

> 更多短评 144978条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 七宗罪的影评 · · · · · · ( 全部 2059 条 )

热门 / 最新 / 好友
香草美人 2005-12-30 00:05:23

## 绝望的《七宗罪》

昨天深夜看完了《七宗罪》。 这是一部有浓厚宗教色彩的片子，看到片名，就想起与之相似的《第七封印》。如果说伯格曼在《第七封印》中对信仰的根源和上帝的存在进行了追问和探讨，那么《七宗罪》展示的就是如果丢掉信仰，世界将会怎样。 影片中的纽约，灰暗、潮湿、肮脏、混乱... (展开)
5022 684 518回应 收起
CelticTwilight 2008-07-14 00:50:39

## 关于结局 关于7sins的些许

这篇影评可能有剧透

看完了影片，影片却没有结束，老Somerset最后的一句“I'll be around”不是像一般电影一样甩尾式的一个解脱，而是在短短一周后7sins对他出租车上“far away from here”的沉重的改变，这种改变交出的代价是血淋淋的血，和黑漆漆的黑。编导用十几月精心安设每一处细节让我们... (展开)
2789 196 301回应 收起
你读书少♂ 2019-06-08 18:36:24 #《七宗罪》体现了大卫·芬奇的什么风格？

## 从《七宗罪》来看大卫芬奇的视听语言呈现

这篇影评可能有剧透

体现了他纯视听，纯电影的思维方式。 和国内那些只会拍对话的导演不一样。大卫芬奇也许是当代最接近希区柯克的导演。虽然他们两个风格几乎完全不同，但一样的是他们对镜头语言的运用极具品味。他们是真正的用视听思维在表现悬念。而不是用念白一样的方式，把一些具有悬念的文字... (展开)
693 4 35回应 收起
似水微『澜』 2006-05-24 02:22:53

## 行而上的意义

这篇影评可能有剧透

1.暴食、贪婪、淫欲、懒惰、骄傲、嫉妒、复仇，有种宗教上的道德劝诫的警世意味。 罪犯严密的犯罪逻辑，是本片的线索。从前五种罪来看，罪犯没有过错，起码是在替天行道，要说错也是社会的过，而最后的“嫉妒”和“复仇”正是本片的争议之处：在罪犯看来，大卫枪杀自己... (展开)
486 71 81回应 收起
stiloabarth 2009-12-12 03:17:18

## 很操蛋的电影（偷换概念）---约翰罪不在嫉妒，而是走极端

影片看完感觉很操蛋----难道约翰有点对？--你看，miller不是中其下怀么。 细想完全不是这么回事，影片引导向错误方向。 结论：miller确实错了，不该冲动开枪，但绝对不能以此误认为约翰有哪怕一点点对的成分而加以想象，恰恰相反，根据影片阐述的本旨，约翰才... (展开)
497 156 110回应 收起
安那其主义 2009-12-21 21:20:27

## 古典主义的行为艺术——《七宗罪》浅评

这篇影评可能有剧透

在尼采高呼出：“上帝死了”时我们的古典生活被宣判结束。现代化的城市生活，在无限缩小着世界间的距离，人们并没有因此而更加亲密，反而是疏离和冷漠将其取而代之，就连那仅存的藏有古典情怀的爱情，也让赤裸裸的肉欲推翻在地，所有的悠长和浪漫，都变的短暂而破碎，这就是我... (展开)
384 25 30回应 收起
和翧 2007-11-17 14:57:25

## 七宗罪的一些问题与思考

这篇影评可能有剧透

一些问题与思考.不算影评吧.不知道起什么标题,本想写无题的. :-) 新老侦探的对比很鲜明: 特别是在酒吧里面对话的那一段,点出了两者不同的态度: 一个稳重,阅历丰富然而无奈,选择逃避的老者, 和一个冲动,情绪化,还带着乐观的认为可以改变世界的年轻人. 还有办案的手法,每个场景... (展开)
294 38 41回应 收起
yangyeyystc 2012-01-20 20:50:00

## 为什么说《七宗罪》是牛逼的电影

这篇影评可能有剧透

对于这部影片来说，七宗罪以及其中一些有关宗教的理解也好，书籍也好，概念也好，都是一种借口，一件外衣，电影只是以宗教之名来表达某些更深层次的东西。所以，在分析这部影片之前，不妨首先揭开这层宗教外衣的笼罩。 宗教来源于人类对自然的认知，当然“自然”中... (展开)
334 91 85回应 收起
吴非非 2008-02-14 23:30:27

## Se7en·辩护书

我有罪，不致死。 Gluttony （饕餮是因为轻易） 　　饕餮者不用嘴，每个细胞都哭泣着同来摄入。最深的饕餮都藏在黑夜里，一天中最无需进食的时刻，只因欲望进食的时刻，生之空间豁开口子，遗下饕餮者在此不得进入，遗下他脂油堆积的身体、肥厚回绕的肠、如果行走将层层抖动... (展开)
156 36 17回应 收起

> 更多影评 2059篇

添加新讨论

## 讨论区 · · · · · ·

Tracy并没有凋零，被错误解读26年的电影！ | 来自大卫.分奇 | 97 回应 | 2022-11-23 16:35:30
为什么还会有人觉得Tracy没死啊？ | 来自乔瓦娜 | 6 回应 | 2022-11-21 13:46:28
Tracy 死了吗？ | 来自腹肌撕裂er | 1 回应 | 2022-11-21 13:44:18
如果你是Pitt,会开枪吗？ | 来自欢崽同学 | 126 回应 | 2022-11-19 10:49:47
不孝应该是诸罪之首吧，竟然没有。 | 来自豆友199786926 | 18 回应 | 2022-11-19 10:46:34

> 去这部影片的讨论区（全部483条）

## 关于《七宗罪》的问题 · · · · · · ( 全部67个 )

- 摩根最后的行为？ 4人回答
- 老警官为什么不骗一下pitt，让他自己去确认包裹，拖延一下时间？ 6人回答

> 全部67个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 他们是高智商玩家 (中间元素)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)

## 谁在看这部电影 · · · · · ·

- 嘎爵爷
  5分钟前 看过
- 现在时间上午十
  7分钟前 想看
- 没什么说说
  7分钟前 看过

1401435人看过 / 371268人想看

订阅七宗罪的评论:
feed: rss 2.0